summaryrefslogtreecommitdiffstats
path: root/bin/test_torbrowser-launcher.sh
diff options
context:
space:
mode:
Diffstat (limited to 'bin/test_torbrowser-launcher.sh')
-rwxr-xr-xbin/test_torbrowser-launcher.sh6
1 files changed, 3 insertions, 3 deletions
diff --git a/bin/test_torbrowser-launcher.sh b/bin/test_torbrowser-launcher.sh
index c06a3b92..b0314a5e 100755
--- a/bin/test_torbrowser-launcher.sh
+++ b/bin/test_torbrowser-launcher.sh
@@ -260,10 +260,10 @@ download_and_launch() {
if [ -n "$SETTINGS_DONE" ] ; then
announce_failure_and_exit "$(date -u) - settings dialog still there, please investigate."
fi
# allow the download to take up to ~15 minutes (891 seconds)
# ( echo -n "0" ; for i in $(seq 1 33) ; do echo -n "+$i+10" ; done ; echo ) | bc
# we watch the download directory and parse torbrowser-launchers stdout, so usually this loop won't run this long
- for i in $(seq 1 33) ; do
+ for i in $(seq 1 42) ; do
sleep 10 ; sleep $i
STATUS="$(grep '^Download error:' $TBL_LOGFILE || true)"
if [ -n "$STATUS" ] ; then
@@ -260,10 +260,10 @@ download_and_launch() {
announce_failure_and_exit "$(date -u) - settings dialog still there, please investigate."
fi
- # allow the download to take up to ~15 minutes (891 seconds)
- # ( echo -n "0" ; for i in $(seq 1 33) ; do echo -n "+$i+10" ; done ; echo ) | bc
+ # allow the download to take up to ~22 minutes (1323 seconds)
+ # ( echo -n "0" ; for i in $(seq 1 42) ; do echo -n "+$i+10" ; done ; echo ) | bc
# we watch the download directory and parse torbrowser-launchers stdout, so usually this loop won't run this long